<?php

/*
 *	Article System
 *	Online journal management tool
 written in PHP/MySQL.
 *	This code is available at http://sourceforge.net/projects/artsys
 *
 *	Copyright (C) 2002 Jan Hnatek
 *	Distributed under the terms of the GNU General Public License
 *
 *	Date:	  07/05/2002
 *	Version:  0.1-1 (pre-alpha)      	
 */

###############################################################################
# button : an abstract object ArtSys submenu buttons

/**
 *	An abstract class representing a button in ArtSys submenu (in module menu).
 *	
 *	@author		Jan Hnatek
 */
class menu_button {
//---------------//

	// VARIABLES
	
	/**	Name of the button.
	 *	The name="" value.
	 * 	@var		string
	 * 	@access		private
	 */
	var $name;
	
	/**	Label of this button.
	 *	The text, which will be displayed on the button, ie. the value="".
	 *	@var	string
	 *	@access	private
	 */
	var $label;
	
	/** Target section.
	 *	The link bound to this button will lead to given section.
	 *	@var	string
	 *	@access	private
	 */
	var $tsec;
	/** Target subsection.
	 *	The link bound to this button will lead to given subsection.
	 *	@var	string
	 *	@access	private
	 */
	var $tsub;
	/** Script contents.
	 *	// in subclasses: Name of the script function, that will be used to redirect after pressing the button.
	 *	@var	string
	 *	@access	private
	 */
	var $script = "linkto";

	// CONSTRUCTOR
	
	/**	Constructor of the class.
	 *	This is just an example, it's recommended to override in subclasses to simplify input.
	 *	
	 *	@param	$isec string Target section.
	 *	@param	$isub string Target subsection
	 *	@param	$ilabel string Label of this button
	 *	@param	$iname string Name of the button
	 *	@param	$iscript string Script for this button.
	 *	@param	$iadd string addition ???
	 *	@return	void
	 *	@access	public
	 *	
	 *	@see	display()
	 */
	function menu_button ($isec, $isub, $ilabel, $iname, $iscript) {
		$this->name = $iname;
		$this->label = $ilabel;
		$this->tsec = $isec;
		$this->tsub = $isub;
		$this->script = $iscript;
	}

	// METHODS
	
	/**	Echoes results of render() function.
	 *	@return void
	 *	@access public
	 */
	function display () {
		echo $this->render();
	}
	
	/**	Plain rendering function. 
	 *	A 'virtual' function rendering the button.
	 *	This implementation of this function is the default, 
	 *	it may be overridden in sub-classes.
	 *	This is just the default, or example.
	 *	It is called by display() function
	 *	@return string
	 *	@access private
	 */
	function render () {
		if ($this->tsub != "")
			$tmp = "&sub=".$this->tsub;
		return "<input \n\ttype=\"Button\" \n\tname=\"".$this->name."\" \n\tvalue=\"".$this->label."\"
	onclick=\"$this->script\">";
	}
}


###############################################################################
# default scripted button

class link_button extends menu_button {
//-----------------------------------//

	var $script_args = '';

	/**	Custom constructor.
	 *	Script here is meant to be a function name ONLY.
	 *	@param $iscript	Name of the script function, that will be used to redirect after pressing the button.
	 */
	function link_button ($isec, $isub, $ilabel, $iname, $iscript, $iadd='') {
		$this->name = $iname;
		$this->label = $ilabel;
		$this->tsec = $isec;
		$this->tsub = $isub;
		$this->script = $iscript;
		$this->script_args = $iadd;
	}

	/*	<code>script</code> here is meant to be only a function name.
	 *	Still 'virtual'.
	 *	This implementation of this function is the default, 
	 *	it may be overridden in sub-classes.
	 *	This is just the default, or example.
	 *	It is called by display() function
	 *	@return string
	 *	@access private
	 */
	function render () {
		global $BASE_ADMIN_URL;
		if ($this->tsub != "")
			$tmp = "&sub=".$this->tsub;
		if ($this->script_args == "")
			$script = "$this->script ('$BASE_ADMIN_URL/main.php?sec=".$this->tsec.$tmp."')";
		else
			$script = "$this->script ('$BASE_ADMIN_URL/main.php?sec=".$this->tsec.$tmp."', ".$this->script_args.")";
	/* nicer 
		return "<a href=\"#\" name=\"".$this->name."\" onclick=\"$script\">".$this->label."</a>";
	/* NN4.7 friendlier */
		return "<input \n\ttype=\"Button\" \n\tname=\"".$this->name."\" \n\tvalue=\"".$this->label."\"
	onclick=\"$script\">";
	/**/
	}
}

###############################################################################
# custom, often used predefined buttons:


class button_reset extends link_button {
//------------------------------------//

	function button_reset ($ilabel) {
		$this->label = $ilabel;
	}
	function render () {
		global $BASE_ADMIN_URL;
		return "<input \n\ttype=\"reset\" value=\"".$this->label."\">";
	}
}

class button_new extends link_button {
//----------------------------------//
	function button_new ($isec, $ilabel) {
		global $subsection;
		$this->tsec = $isec;
		$this->tsub = "new";
		$this->label = $ilabel;
		$this->name = "new";
		$this->script = "linkto";
	}
}

class button_edit extends link_button {
//-----------------------------------//
	function button_edit ($isec, $ilabel) {
		global $subsection;
		$this->tsec = $isec;
		$this->tsub = "edit";
		$this->label = $ilabel;
		$this->name = "edit";
		$this->script = ($subsection == "list") ? "linklistto" : "linkto";
	}
}

class button_delete extends link_button {
//-------------------------------------//
	function button_delete ($isec, $ilabel, $msg) {
		global $subsection;
		$this->tsec = $isec;
		$this->tsub = "delete";
		$this->label = $ilabel;
		$this->name = "delete";
		$this->script = ($subsection == "list") ? "confirmlinklistto" : "confirmlinkidto";
		$this->script_args = "'$msg'";
	}
}

class button_save extends link_button {
//-----------------------------------//
	function button_save ($isec, $ilabel, $iscriptfn="") {
		global $subsection;
		$this->tsec = $isec;
		$this->tsub = "edit";
		$this->label = $ilabel;
		$this->name = "save";
		if ($iscriptfn == "")
			$this->script = ($subsection == "list") ? "linklistto" : "linkto";
		else
			$this->script = $iscriptfn;
	}
	function render () {
		global $BASE_ADMIN_URL;
		if ($this->tsub != "")
			$tmp = "&sub=".$this->tsub;
		// 'Submit' doesn't pass on querystring variables, so we don't have to set them
	 	return "<input \n\ttype=\"Submit\" \n\tname=\"".$this->name."\" \n\tvalue=\"".$this->label."\"
	onclick=\"$this->script ('$BASE_ADMIN_URL/main.php')\">";
	}
}

class button_next extends button_save {
//-----------------------------------//
	function button_next ($isec, $ilabel, $iscriptfn="") {
		global $subsection;
		button_save::button_save ($isec, $ilabel, $iscriptfn);
		$this->name = "next";
	}
}

// TODO : ??? class button_prev extends link_button {

class button_done extends link_button {
//-----------------------------------//
	function button_done ($isec, $ilabel="") {
		global $subsection;
		$this->tsec = $isec;
		$this->tsub = "list";
		$this->label = ($ilabel == '') ? msg("done") : $ilabel;
		$this->name = "done";
		$this->script = ($subsection == "list") ? "linklistto" : "linkto";
	}
}

?>