<?php

/*
 *	Article System
 *	Online journal management tool
 written in PHP/MySQL.
 *	This code is available at http://sourceforge.net/projects/artsys
 *
 *	Copyright (C) 2002 Jan Hnatek
 *	Distributed under the terms of the GNU General Public License
 *
 *	Date:	  07/05/2002
 *	Version:  0.1-1 (pre-alpha)      	
 */

###############################################################################

/**
 *	Client part support for Article System.<br>
 *	A set of database querying methods for getting client part data
 *	from the Article System database.
 *
 *	@author	Jan Hnatek
 */
class client {

    // VARIABLES
    //
	var $articles;
	var $agroups;
	var $issues;
	var $active_issue;
	var $active_article;
	var $article;

	var $error;

	// CONSTRUCTOR
	//
	/**	Contructor of client class.<br>
	 *	@access	public
	 */
	function client (&$a, &$g, &$i, $ai='') {
		global $db;
    	$this->articles = $a;
        $this->agroups = $g;
        $this->issues = $i;
        if (is_numeric ($ai))
			$this->active_issue = $ai;
    	$this->connect ();
	}


// COMMON METHODS
//
	/**	Connect to the database.
	 *	@access	public
	 *	@return	boolean
	 */
	function connect () {
		// FIXME: TOGGLE persistent off, disable old way of opening db
		global $db;
		$db->open (0);
	}


// ISSUE METHODS
//
	/**	Returns data on currently active issue.
	 *	Namely 'id, name, subtitle'.
	 *	@return associative array
	 */
	function get_current_issue () {
		return $this->issues->get_one ('id, name, subtitle', "WHERE current='1'");
	}
	/**	Returns data on issue given by id, which is currently archived.
	 *	Namely 'id, name, subtitle'.
	 *	@return associative array
	 */
	function get_archived_issue ($id) {
		return $this->issues->get_one ('id, name, subtitle', "WHERE archived='1' AND id='$id'");
	}
	/**	Returns next archived issue id from given $id.
	 *
	 */
	function get_next_archived_issue ($id) {
		// TODO:
		return $id +1;
	}
	/**	Returns previous archived issue id from given $id.
	 *
	 */
	function get_previous_archived_issue ($id) {
		// TODO:
		return $id -1;
	}
	/**	Returns data on archived issues.
	 *	Namely 'id, name, subtitle' for each of them.
	 *	@return associative array
	 */
	function get_issue_archive () {
		return $this->issues->get ('id, name, subtitle', "WHERE archived='1'");
	}
	/**	Returns basic data of articles in given issue.
	 *	Namely 'id, title, menu_title, menu_group, iorder'.
	 *	The list is ordered by 'iorder'.
	 *	@param	$id	Id of an issue
	 *	@return array of associative arrays
	 */
	function get_issue_articles ($id) {
		return $this->articles->get_issue ($id, 'A.id, A.title, A.menu_title, A.menu_group, A.iorder');
	}
	/**	Returns menu of given issue as linkset class.
	 *	The data contained are in form (menu_group, menu_title, menu_group, menu_title, ..) or
	 *	just plain array of menu_titles (menu_title, menu_title, ...).<br>
 	 *	The list is ordered by 'iorder'.<br><br>
	 *	Use <code>linkset</code> methods <code>get_plain</code> for menu_group items and
	 *	<code>get_link</code> for menu_title items.
	 *	@param	$id	Id of an issue
	 *	@param	$menu_group Boolean to specify, whether get 'menu_group' data too)
	 *	@return array of associative arrays
	 *	@see linkset
	 */
	function get_issue_menu ($id, $menu_group=true) {
		$a_set = $this->articles->get_issue ($id, 'A.id, A.menu_title, A.menu_group');
		if (!$a_set) {
			$this->articles->error_report ();
			return false;
		}
		$links = array ();
		foreach ($a_set as $a) {
			if ($menu_group)
				array_push ($links, array ("", $a['menu_group']));
   			array_push ($links, array ($a['id'], $a['menu_title']));
   		}
		return new linkset ($links);
	}
	/**	Test if given issue id is of archived issue.
	 *	Use to prevent displaying of non-public issues.
	 *	@param	$id	Id of an issue
	 *	@return string
	 */
	function is_archived ($id) {
		// TODO
		return true;
	}


// ARTICLE METHODS
//
	/**	Fill in local var and return detailed article data of given article.
	 *	@param	$id	Id of an article
	 *	@return associative array
	 */
	function get_article ($id) {
		$this->article = $this->articles->get_one ('id, title, subtitle, content, signature', "WHERE id='$id'");
		return $this->article;
	}
	/**	Return specified part of last loaded (with get_article) article.
	 *	@param	$what	Column name from Articles.
	 *	@return string
	 */
	function get_adata ($what) {
 		//if (!$this->article) {
		return $this->article[$what];
	}
	/**	Test if given article id is from current issue.
	 *	Use to prevent displaying of non-public articles.
	 *	@param	$id	Id of an article
	 *	@return string
	 */
	function is_current ($id) {
		// TODO
		return true;
	}
	/**	Fill in local var and return detailed article data of given article.
	 *	Restriction to articles is specified as parameter.
	 *	@param	$id	Id of an article
	 *	@param	$restrict Restrictions to apply.
	 *	@param	$what Columns to return: select from { Articles A, Users U, Issues I }. Comma separated.
	 *	@access	private
	 *	@return associative array
	 */
	function get_article_special ($id, $restrict, $what='A.id, A.title, A.subtitle, A.content, A.signature') {
		global $db;
		$result = array ();
		// this is from get_article()
		;
		// FIXME: or this ?
		// "SELECT A.id, A.title, U.name FROM Articles A, Users U WHERE A.author=U.id AND A.issue = '$iname'"
		// NOTE: this routine is modification od db_articles->get_issue(), so see that first
		$RS = $db->exec ("SELECT DISTINCT $what FROM Articles A, Users U, Issues I
			WHERE (A.author=U.id) AND (A.issue=I.id) AND $restrict AND (A.id = '$id')
			ORDER BY A.iorder"); //, 1);
		if (!$RS) {
			$this->error = $db->report (msg ("select fail"));
			return false;
		}
		return $db->get_result_array ();
	}
	/**	Fill in local var and return detailed article data of given article.
	 *	Restricted to articles of current issue.
	 *	@param	$id	Id of an article
	 *	@access	public
	 *	@return associative array
	 */
	function get_current_article ($id) {
		return $this->get_article_special ($id, "(I.current='1')");
  	}
	/**	Fill in local var and return detailed article data of given article.
	 *	Restricted to articles of archived issues.
	 *	@param	$id	Id of an article
	 *	@access	public
	 *	@return associative array
	 */
	function get_archived_article ($id) {
		return $this->get_article_special ($id, "(I.archived='1')");
  	}

	/**	Return specified part of last loaded (with get_article) article with custom formatting.
	 *	@param	$what	Column name from Articles.
	 *	@return string
	 */
	function get_formatted ($what) {
		switch ($what) {
		case "signature" :
			return $this->format_signature ($this->article[$what]);
			break;
		case "subtitle" :
			return "<i>". $this->article[$what] ."</i>";
			break;
		}
	}
	/**	Return formatted signature from an unformatted one.
	 *	@param	$text	The text of unformatted signature.
	 *	@return string
	 */
	function format_signature ($text) {
		// strip newlines
		$text = preg_replace ( "/[\r\n]+/", "<br>", $text);
		// merge a line with the next one, if the next one is an email address
		$text = preg_replace (
			"/([\w\ ]*)<br>([\.\w]*@[\.\w]*)/mi",
			"<a href=\"mailto:\\2\">\\1</a>",
			$text);
		return $text;
	}


// GROUP METHODS
//
	/**	Return list of exported article groups.
	 *	For each of them returns 'id, name, menu_text, description'.<br>
	 *	Default ordering by 'menu_text' ascending.
	 *	@param	$how	Optional WHERE/ORDER clause that overrides the default ordering.
	 *	@return array of asoc.arrays
	 */
	function get_groups ($how="WHERE exported='1' ORDER BY menu_text ASC") {
		return $this->agroups->get ('id, name, menu_text, description', $how);
	}
	/**	Return group data of group specified by given column name and it's value.
	 *	The data contains 'id, name, menu_text, description'.<br>
	 *	@param	$col	Name of the column which $val is data from.
	 *	@param	$val	Value to specify the wanted group.
	 *	@return asoc.array
	 */
	function get_group_by ($col, $val) {
	 	return $this->agroups->get_one ('id, name, menu_text, description', "WHERE exported='1' AND $col='$val'");
	}
	/**	Return data of group specified by id.
	 *	The data contains 'id, name, menu_text, description'.<br>
	 *	@param	$id	Id of a group.
	 *	@return asoc.array
	 */
	function get_group ($id) {
		return $this->get_group_by ('id', $id);
  	}
	/**	Returns basic data of articles of given group.
	 *	Namely 'A.id, A.title, A.menu_title, A.issue, U.name', as this is the default for <code>get_group</code>.
	 *	The list is ordered by A.issue ascending.
	 *	@param	$id	Id of an issue
	 *	@return array of associative arrays
	 */
	function get_group_articles ($id) {
		return $this->articles->get_group ($id);
	}



	// TEMPORARY / TESTING METHODS
	//
	/**	Get an issue to display with respect to fake issue input.
	 *	@return asoc.array $issue ('id', 'name', ..)
	 */
	// TODO: check active session in db ??? .. fake issue login should be authenticated ???
	// TODO: fake issues : check referrer !!! ??? how ???
	// TODO: set different user_id for admin ???
	function test_fake_issue (&$user, $fake_active_issue, $fake) {
		// we don't want both to be set
		if (isset ($fake_active_issue))
			unset ($fake);
		if (isset ($fake)) {
			// we got fake issue id from previous session
			$issue['id'] = $fake;
			debug ("fake: ". $issue['id']);
		} else {
			// we have to set $fake, if $fake_active_issue is set
			if (isset ($fake_active_issue)) {
				// check rights for issue management
				if ($user->check_my ("issues")) {
					$issue['id'] = $fake_active_issue;
					$fake = $issue['id'];
					debug ("fake: ".$issue['id']);
				} else
					$issue = $this->get_current_issue ();
			} else
				$issue = $this->get_current_issue ();
		}
		return $issue;
	} // test_fake_issue()


	/**	An example of article rendering function.
	 *	@param	$article	Id of an article to display.
	 */
	// TODO: should be probably rendered with help of $gui
	function display_article ($article) {
		if (is_numeric ($article)) {
			// TODO: test if in current issue
			$this->get_article ($article);	?>
		<table width="500" align="center" border="0" cellpadding="0" cellspacing="0">
		<!-- article title -->
		<tr><td bgcolor="#808080" align="center">
<?			echo "<b>". $this->get_adata ('title') ."</b>\n"; ?>
		</td></tr>
		<!-- article subtitle -->
		<tr><td>
		<br>
<?			echo "<p>". $this->get_formatted ('subtitle') ."</p>\n"; ?>
		</td></tr>
		<tr><td>
		<br>
		<!-- article content -->
<?			echo "<p>". $this->get_adata ('content') ."</p>\n"; ?>
		<br>
		</td></tr>
		<!-- author signature -->
		<tr><td bgcolor="#c0c0c0" align="right">
<?			echo "<p>". $this->get_formatted ('signature') ."</p>\n"; ?>
		</td></tr>		
		</table>
<?		}
	} // display_article()


} // class client
