<?php

/*
 *	Article System
 *	Online journal management tool
 written in PHP/MySQL.
 *	This code is available at http://sourceforge.net/projects/artsys
 *
 *	Copyright (C) 2002 Jan Hnatek
 *	Distributed under the terms of the GNU General Public License
 *
 *	Date:	  07/05/2002
 *	Version:  0.1-1 (pre-alpha)      	
 */

###############################################################################

/**	
 *	Abstract class for Articles entity in ArtSys DB.<br>
 *	Contains custom <code>SELECT</code> SQL queries.
 *
 *	@author	Jan Hnatek
 */
class db_articles extends db_entity {

	// CONSTRUCTOR
	//
	/**	Contructor of db_articles class.<br>
	 *	@access	public
	 */
	function db_articles () {
		$this->name = "Articles";
	}

	// METHODS
	//
	/**	Returns all articles in given exported group.
	 *	@param	$id	The 'id' value of a group.
	 *	// TODO: exported as parameter ???? in all group manip. functions ???
	 *	@param	$what Columns to return: select from { Articles A, Users U, Issues I }. Comma separated.
	 *	@access	public
	 *	@return	query result -> array of assoc. arrays
	 */
	// get all articles in group (or NONE if empty ????)
	function get_group ($id, $what='A.id, A.title, A.menu_title, A.issue, U.name') {
		global $db;
		$this->result = array ();
		// FIXME: or this ?
		// "SELECT A.id, A.title, U.name FROM Articles A, Users U WHERE A.author=U.id AND A.issue = '$iname'"
		// FIXME: ascending order of A.issue does not guarantee the correct order (order by published_on ??)
		$RS = $db->exec ("SELECT DISTINCT $what FROM Articles A, Users U, Agroups G, Ainsertion I
			WHERE (A.author=U.id) AND (A.id=I.article) AND (G.id=I.agroup) AND (G.id='$id') AND G.exported='1'
			ORDER BY A.issue ASC"); //, 1);
		if (!$RS) {
			$this->error = $db->report (msg ("select fail"));
			return false;
		}
		while ($row = $db->get_result_array ())
			array_push ($this->result, $row);
		return $this->result;
	}

	/**	Returns all groups of given article.
	 *	@param	$aid	int		The 'id' value of an article.
	 *	@access	public
	 *	@return	query result -> array of assoc. arrays
	 */
	function get_my_groups ($aid) {
		// FIXME: SHOULD BE IN $groups ????? !!!!!
		global $db;
		$this->result = array ();
		$RS = $db->exec ("SELECT G.id, G.name FROM Ainsertion A, Agroups G WHERE article='$aid' AND A.agroup=G.id", 1);
		if (!$RS) {
			$this->error = $db->report (msg ("select fail"));
			return false;
		}
		while ($row = $db->get_result_array ())
			array_push ($this->result, $row);
		return $this->result;
	}

	/**	Returns true/false depending on whether given article is in given group.
	 *	@param	$aid	int		The 'id' value of an article.
	 *	@param	$gid	int		The 'id' value of a group.
	 *	@access	public
	 *	@return	bool
	 */
	function get_me_in_group ($aid, $gid) {
		global $db;
		$db->exec ("SELECT * FROM Ainsertion WHERE (article='$aid') AND (agroup='$gid')", 1);
		return $db->num_rows ();
	}

	/**	Returns all articles in given issue.
	 *	@param	$issue	int		The 'id' value of an issue.
	 *	@param	$what	string	Columns to return: select from { Articles A, Users U, Issues I }. Comma separated.
	 *	@access	public
	 *	@return	query result -> array of assoc. arrays
	 */
	function get_issue ($issue, $what='A.id, A.title, A.menu_title, U.name') {
		global $db;
		$this->result = array ();
		// FIXME: or this ?
		// "SELECT A.id, A.title, U.name FROM Articles A, Users U WHERE A.author=U.id AND A.issue = '$iname'"
		$RS = $db->exec ("SELECT $what FROM Articles A, Users U, Issues I
			WHERE (A.author=U.id) AND (A.issue=I.id) AND (I.id='$issue')
			ORDER BY A.iorder"); //, 1);
		if (!$RS) {
			$this->error = $db->report (msg ("select fail"));
			return false;
		}
		while ($row = $db->get_result_array ())
			array_push ($this->result, $row);
		return $this->result;
	}

	/**	Returns all 'new' articles, ie. articles, which are not in any issue.
	 *	@param	$what	string	Columns to return: select from { Articles A, Users U }. Comma separated.
	 *	@access	public
	 *	@return	query result -> array of assoc. arrays
	 */
	function get_new ($what='A.id, A.title, U.name') {
		global $db;
		$this->result = array ();
		$RS = $db->exec ("SELECT $what FROM Articles A, Users U WHERE A.author=U.id AND A.issue IS NULL AND A.approved='1'"); //, 1);
		if (!$RS) {
			$this->error = $db->report (msg ("select fail"));
			return false;
		}
		while ($row = $db->get_result_array ())
			array_push ($this->result, $row);
		return $this->result;
	}

} // class db_articles

?>