<?php

/*
 *	Article System
 *	Online journal management tool
 written in PHP/MySQL.
 *	This code is available at http://sourceforge.net/projects/artsys
 *
 *	Copyright (C) 2002 Jan Hnatek
 *	Distributed under the terms of the GNU General Public License
 *
 *	Date:	  07/05/2002
 *	Version:  0.1-1 (pre-alpha)      	
 */

###############################################################################
# form_item : abstract object wrappers for HTML form's inputs

// package artsys.forms

/**
 *	An abstract class representing generic form control<br>
 *	based on Yuri Makassiouk's (&lt;racer@bfpg.ru&gt;) FormControl
 *	
 *	@author		Jan Hnatek
 */
class form_item {
//-------------//

	// VARIABLES
	//
	/**	Logical name of a control.
	 *	Corresponds to name of a data element in the containing form
	 * 	@var		string
	 * 	@access		private
	 * 	@see		$form
	 */
	var $Name;
	  
	/**	References the containing form's object.
	 *	Establishes a link between object representing a control of a form and object representing the form
	 *	@var	object form_process
	 *	@access private
	 */
	var $form;
	 
	/**	Holds value for a control that the object will represent
	 *	@var	string
	 *	@access	private
	 */
	var $Value;
	
	/**	Holds a string with control's attributes.
	 *	This would normally be a string containing some formatting attributes that will be embedded in 
	 *	the control's html tag to refine its appearance and/or behaviour
	 *	@var 	string
	 *	@access private
	 */
	var $Attributes;
	
	/**	Holds a copy of containing form's name.
	 *	@var 	string
	 *	@access private
	 */
	var $FormName;
	
	/**	Name of the html input that this object will represent. Do not confuse with $Name!.
	 *	It is a value for the name="" attribute, how it will appear in form's html
	 *	@var 	string
	 *	@access private
	 */
	var $InputName;

	// CONSTRUTOR
	//
	/**	Constructor of the class.
	 *	Given a reference to a containing form's object, examines some its values. 
	 *	Sort of, tunes in the containing form. Then puts control's code to the output stream by calling 
	 *	display() member function
	 *	
	 *	@param	$Aform object form_process A reference to the object representing containing form
	 *	@param	$AName string Logical name for the control
	 *	@param	$AValue string Value that initializes the control when it is displayed for the first time
	 *	@param	$AAttributes string Usually would be a fragment of input's tag 
	 *			containing some attributes refining control's appearance and behaviour
	 *	@return	void
	 *	@access	public
	 *	
	 *	@see	display()
	 */
	function form_item ($Aform, $AName, $AValue='', $AAttributes='') {
		$this->Name = $AName;
		$this->form = $Aform;
		$this->Value = ($this->form->FirstTime) ? addslashes ($AValue) : ($this->form->Values[$this->Name]);
		//debug ("new value of $AName:".$this->Value."/".$AValue);
		$this->Attributes = $AAttributes;
		$this->FormName = $Aform->Name;
		$this->InputName = sprintf("%s%s[%s]", $this->form->fieldPrefix, $this->FormName, $this->Name);
		
		$this->display();
	}

	// METHODS
	//
	/**	Echoes name of the input.
	 *	Why do we need it? Probably for a shortcut..
	 *	@return void
	 *	@access public
	 */
	function input_name () {
		echo $this->InputName;
	}
	
	/**	Echoes results of render() function.
	 *	This function is called by constructor, so that applications may place control in html by simply instantiating a required class
	 *	@access public
	 *	@return void
	 */
	function display() {
		echo $this->render();
	}
	
	/**	An abstract function rendering a control.
	 *	This function must be overridden in sub-classes to render  the control's html code. It is called by Display() function
	 *	@return string
	 *	@access private
	 */
	function render() {}
		//abstract
	}

?>
