<?php

/*
 *	Article System
 *	Online journal management tool
 written in PHP/MySQL.
 *	This code is available at http://sourceforge.net/projects/artsys
 *
 *	Copyright (C) 2002 Jan Hnatek
 *	Distributed under the terms of the GNU General Public License
 *
 *	Date:	  07/05/2002
 *	Version:  0.1-1 (pre-alpha)      	
 */

###############################################################################
# form_items : simple abstract object wrappers for HTML form's inputs

// package artsys.forms

/**	
 *	Class representing text value (NOT a *form* item, just a string).<br>
 *	This is just a value container.
 * 	
 *	@parent	form_item
 */
class form_string extends form_item {
//---------------------------------//
	function render() {
    	return htmlspecialchars (stripslashes ($this->Value));
	}
}

/**
 * Class representing a hidden control
 * 
 * @parent	form_item
 */
class form_hidden extends form_item {
//---------------------------------//
	function render() {
    	return "<input type=\"Hidden\" name=\"$this->InputName\" value=\"". stripslashes (htmlspecialchars ($this->Value)) ."\">";
	}
}

/**
 * Class representing a text control.<br>
 * Set size="" in attributes for this class !
 * 
 * @parent	form_item
 */
class form_text extends form_item {
//-------------------------------//
	function render() {
		//echo $this->Value;
    	return "<input type=\"Text\" name=\"$this->InputName\" value=\"". 
		htmlspecialchars (stripslashes ($this->Value)) ."\" $this->Attributes>";
	}
}

/**	
 *	Class representing a password text control.<br>
 * 	It just doesn't set the value="" attribute for obvious reasons.
 *	Set size="" in attributes for this class !
 *	
 *	@parent	form_item
 */
class form_password extends form_item {
//-----------------------------------//
	function render() {
		return "<input type=\"Password\" name=\"$this->InputName\" $this->Attributes>";
	}
}

/**
 * Class representing a text area.<br>
 * Set rows="" and cols="" in attributes for this class !
 * 
 * @parent	form_item
 */
class form_textarea extends form_item {
//-----------------------------------//
	function render() {
		return "<textarea name=\"$this->InputName\" $this->Attributes>". stripslashes (htmlspecialchars ($this->Value)) ."</textarea>";
	}
}

/**
 * Class representing a checkbox
 * 
 * @parent	form_item
 */
class form_checkbox extends form_item {
//-----------------------------------//
	/**	Custom render.
	 *	Checkbox does not export its value parameter, it's either "on" or anything.
	 */
	function render() {
		if ($this->Value != "on")
			return "<input type=\"CheckBox\" name=\"$this->InputName\" $this->Attributes>";
		else
			return "<input type=\"CheckBox\" checked name=\"$this->InputName\" $this->Attributes>";
	}
}

/**
 * Class representing a button
 * 
 * @parent	form_item
 */
class form_button extends form_item {
//---------------------------------//
	function render() {
    	return "<input type=\"Button\" name=\"".$this->InputName."\" value=\"$this->Value\" $this->Attributes>";
	}
}

/**	
 *	Class representing a submit button.
 *	Submit doesn't alter it's value="" (ie. button's label) attribute after submitting.
 *	
 *	@parent	form_item
 */
class form_submit extends form_item {
//---------------------------------//
	function form_submit ($Aform, $AName, $AValue='', $AAttributes='') {
		$this->Name = $AName;
		$this->form = $Aform;
		$this->Value = $AValue;
		$this->Attributes = $AAttributes;
		$this->FormName = $Aform->Name;
		$this->InputName = sprintf("%s%s[%s]", $this->form->fieldPrefix, $this->FormName, $this->Name);
		
		$this->display();
	}
	function render() {
    	return "<input type=\"Submit\" name=\"$this->InputName\" value=\"$this->Value\" $this->Attributes>";
	}
}

/**
 * Class representing a select box
 * 
 * @parent	form_item
 */
class form_select extends form_item {
//---------------------------------//

	/**	Set of options.
	 *	Array of options, which can be selected through this select box.
	 *	@var 	array
	 *	@access private
	 */
	var $Options = array ();
	
	/**	Constructor of the class.
	 *	Accepts the $options array among other params from form_item contructor. 
	 *	@param	$options array An array of options to use.
	 *	@return	void
	 *	@access	public
	 *	
	 *	@see	form_item
	 *	@see	display()
	 */
	function form_select ($Aform, $AName, $options, $AValue='', $AAttributes='') {
		$this->Name = $AName;
		$this->form = $Aform;
		$this->Options = $options;
		$this->Value = ($this->form->FirstTime) ? $AValue : ($this->form->Values[$this->Name]);
		$this->Attributes = $AAttributes;
		$this->FormName = $Aform->Name;
		$this->InputName = sprintf("%s%s[%s]", $this->form->fieldPrefix, $this->FormName, $this->Name);
		
		$this->display();
	}
	/**	Custom select box rendering routine.
	 *	@return void
	 *	@access	private
	 */
	function render() {
		// render_select_box (name, options, selected, attributes)
		render_select_box ($this->InputName, $this->Options, $this->Value, $this->Attributes);
	}
} // class form_select

?>