<?php

/**	
 *	A container for links with some basic functions.<br>
 *	Should be subclassed and extended to suit your needs.
 *	
 *	<pre>
 	Example:
	$links = array (
		array ("?id=0", "hi"),
		array ("?id=1", "hi 2"),
		array ("?id=2", "hi 3"),
	);
	$ls = new linkset ($links, $id);
 	$ls->reset ();
	while ($link = $ls->get_link ()) {
		if ($ls->selected ())
			echo $ls->get_plain (), "&nbsp;";
		else
			echo $link, "&nbsp;";
		$ls->next ();
	</pre>
 *	
 *	<b>Notes:</b><br>
 *	Using <code>taset</code>: {"a"}<br>
 *	
 *	@author	Jan Hnatek
 */
class linkset {
//-----------//

	// VARIABLES
	//
	/**	Link data, can be one of following:<br>
	 *	2D array in format (("link1", "label1"),  ("link2", "label2"), ..)<br>
	 *	1D array in format ("link1", "link2", ..)<br>
	 *	in the second case, the link label will be the same as the link itself
	 */
	var $data;

	/**	Pointer to the current link, i.e. the one that will be next returned by <code>get_next()</code>.
	 */
	var $current;

	/** Pointer to the selected link, i.e. the one that leads to current page.
	 */
	var $selected;

	/**	Attribute container.
	 */
	var $taset;

	// CONSTRUCTOR
	//
	/**	Constructor of the class linkset. Prepare the data from given array.<br>
	 *	@param	$in		array	Link data, can be one of following:<br>
	 *		2D array in format (("link1", "label1"),  ("link2", "label2"), ..)<br>
	 *		1D array in format ("link1", "link2", ..)<br>
	 *		in the second case, the link label will be the same as the link itself
	 *	@param	$sel	int		Link number of selected link (one that leads to current page)
	 *	@param	$taset	taset	Tag attribute container
	 *	@return void
	 *	@access	public
	 */
	function linkset ($in, $sel="", $taset=0) {
		$this->use_taset ($taset);
		$this->selected = $sel;
		if (is_array ($in)) {
			if (is_array ($in[0]) && count ($in[0]) == 2) {
				// 2D array
				$this->data = $in;
			} else {
				// 1D array, make duplicates (links == labels)
				$this->data = array ();
				foreach ($in as $i)
					array_push ($this->data, array ($i, $i));
			}
		}
	}

	// METHODS
	//
	/**	Render link.
	 *	@param	linknum	int	Index of a link in $data.
	 *	@return string
	 *	@access	private
	 */
	function render_link ($linknum) {
		return '<a href="'.$this->data[$linknum][0].'" '.$this->taset->get ("a").'>'.$this->data[$linknum][1].'</a>';
	}

	/**	Set the <code>taset</code> object to use as the attribute container.
	 *	@return void
	 *	@access	public
	 */
	function use_taset ($taset) {
		if ($taset && is_object ($taset))
			$this->taset = &$taset;
		else
			$this->taset = new taset ();
	}
	/**	Reset the inner pointer to the first link.
	 *	@return void
	 *	@access	public
	 */
	function reset () {
		$this->current = 0;
	}

	/**	Increment inner counter, set current link to the next one in array.
	 *	@return void
	 *	@access	public
	 */
	function next () {
		$this->current++;
	}

	/**	Get current link if any.
	 *	@return string or false
	 *	@access	public
	 */
	function get () {
		if (isset ($this->data[$this->current])) {
			return $this->render_link ($this->current);
		} else
			return false;
	}
	/** Wrapper for <code>get()</code>.
	 *	It's a bit misleading since "link" is the logical name for href part of $data.<br>
	 *	Use <code>get_target</code> to get that information only.
	 *	@see get
	 */
	function get_link () {
		return $this->get ();
	}

	/**	Get label of current link (plain text, no link) if any.
	 *	@return string or false
	 *	@access	public
	 */
	function get_plain () {
		if (isset ($this->data[$this->current])) {
			return $this->data[$this->current][1];
		} else
			return false;
	}

	/**	Get label of current link (plain text, no link) if any.
	 *	@return string or false
	 *	@access	public
	 */
	function get_label () {
		if (isset ($this->data[$this->current])) {
			return $this->data[$this->current][1];
		} else
			return false;
	}
	function get_plain () {
		return $this->get_label ();
  	}

// neither of them does :-(
//	 *	<b>This method doesn't increment the inner pointer,
//	 *	since you are expected to use <code>get_label</code> after this.</b>

	/**	Get href part (target page) of current link (plain text, not as anchor tag) if any.
	 *	@return string or false
	 *	@access	public
	 */
	function get_href () {
		if (isset ($this->data[$this->current])) {
			return $this->data[$this->current][0];
		} else
			return false;
	}
	function get_target () {
		return $this->get_href ();
  	}

	/**	Check if current link is selected.
	 *	@param	$linknum	int	link number, index to $data array
	 *	@return boolean
	 *	@access	public
	 */
	function selected ($linknum="") {
		if ($linknum == "")
			$linknum = $this->current;
		return (is_numeric ($this->selected) && $this->selected == $linknum);
	}

} // class linkset

?>