<?php

/*
 *	Article System
 *	Online journal management tool
 written in PHP/MySQL.
 *	This code is available at http://sourceforge.net/projects/artsys
 *
 *	Copyright (C) 2002 Jan Hnatek
 *	Distributed under the terms of the GNU General Public License
 *
 *	Date:	  07/05/2002
 *	Version:  0.1-1 (pre-alpha)      	
 */

###############################################################################
# subclasses of list_table


// DEBUG : uncomment this to get debug information
//define('LIST_TABLE_DEBUG', true);

/**	
 *	The <code>db_table</code> helps rendering the results of database SELECT queries, 
 *	especially those with many lines, possibly identified by unique id.<br>
 *
 *	@author		Jan Hnatek
 */
class list_table_db extends list_table {
//------------------------------------//

	/**	Custom constructor for <code>list_table_db</code>.
	 *	The <code>$data</code> structure is created here from a given database query result.
	 *	@public
	 *	@param	$rs			database query result
	 *	@param	$db_type	type of database ("mysql" supported only)
	 *	@param	$indent		indentation of the rendered table
	 *	@param	$chall		boolean to enable "select all" button
	 *	@return bool
	 */
    function list_table_db ($rs, $db_type, $indent="", $chall=false, $chname="item_list") {
		// check db_type and get number of results
		switch ($db_type) {
			case "mysql":
			case "MySQL":
				// test input
				if (!$rs)
					return false;
				$this->rows = mysql_num_rows ($rs);
				$this->_debug ("rows: ".$this->rows);
				if (($this->rows == -1) || ($this->rows == 0))
					return false;
				// create $data structure (2D array)
				for ($i=0; $i < $this->rows; $i++)
        			$this->data[$i] = mysql_fetch_row ($rs);
				$this->cols = count ($this->data[0]);
				$this->_debug ("columns: ".$this->cols);
				break;
			default:
				$this->_error ("Database type not supported (use \"mysql\")");
				return false;
		}
		$this->use_indent ($indent);
		$this->check_all = $chall;
		$this->chname = $chname;
	}

} // class list_table_db



/**	
 *	The <code>file_list_table</code> helps rendering the contents of a directory.
 *	
 *	@author		Jan Hnatek
 */
class file_list_table extends list_table {
//--------------------------------------//

	/**	Custom constructor for <code>file_list_table_db</code>.
	 *	Cerates <code>$data</code> structure according to given directory and file mask.
	 *	@public
	 *	@param	$dir		Directory, whose contains should be displayed;
	 *	@param	$mask		File name mask (PERL Regular Expression, see preg_match), 
	 *			use '/.AST/' (where AST=='*') for all files.
	 *	@param	$indent		indentation of the rendered table
	 *	@param	$chall		boolean to enable "select all" button
	 *	@return	bool
	 */
    function file_list_table ($dir, $regex_mask, $indent="", $chall=false, $chname="item_list") {
		// read dir
		$d = dir($dir);
		$this->_debug ("Handle: ".$d->handle."<br>\n");
		$this->_debug ("Path: ".$d->path."<br>\n");
		$this->data = array ();
		$i=0;
		while (false !== ($entry = $d->read()))
			if (($entry != "." && $entry != "..") && preg_match ($regex_mask, $entry)) {
				$row = array ( $i++, $entry );
				array_push ($this->data, $row);
			}
		$d->close();
		
		// check the results
		if (count ($this->data)) {
			$this->rows = count ($this->data);
			$this->cols = count ($this->data[0]);
			$this->_debug ("rows: ".$this->rows);
			$this->_debug ("columns: ".$this->cols);
		} else {
			$this->_error ("input data empty");
			return false;
		}
		$this->use_indent ($indent);
		$this->check_all = $chall;
		$this->chname = $chname;
	}

} // class file_list_table



/**	
 *	The <code>image_browser</code> helps rendering the contents of an image directory with preview buttons.
 *	
 *	@author		Jan Hnatek
 */
class image_browser extends file_list_table {
//-----------------------------------------//

	var $img_types = array (
		1 => "GIF", 2 => "JPG", 3 => "PNG", 
		4 => "SWF", 5 => "PSD", 6 => "BMP"
	);
	var $img_data = array ();

    function image_browser ($dir, $url, $regex_mask, $indent="", $chall=false, $chname="item_list") {
		// read dir
		$d = dir($dir);
		$this->_debug ("Handle: ".$d->handle."<br>\n");
		$this->_debug ("Path: ".$d->path."<br>\n");
		$this->data = array ();
		$i=0;
		while (false !== ($entry = $d->read()))
			if (($entry != "." && $entry != "..") && preg_match ($regex_mask, $entry)) {
				// data: number, filename, img_size
				// img_data: url, width, height, img_code_sizes
				$img_src = $url.'/'.$entry;
				$img = GetImageSize ($dir.'/'.$entry);
				if ($img) {
					//$img_anchor = "<a href=\"$img_src\"". $img[3] . ' target="_blank">'.$entry.'</a>';
					//$row = array ( $i++, $img_anchor, $info);
					$type = $img[2];
					$info = $img[0]."x".$img[1]."x".$this->img_types[$type];
					$row = array ($i++, $entry, $info);
					array_push ($this->img_data, array ($img_src, $img[0], $img[1], $img[3]));
				} else {
					$row = array ($i++, $entry, "failed to read image");
					array_push ($this->img_data, array ());
				}
				array_push ($this->data, $row);
			}
		$d->close();
		
		// check the results
		if (count ($this->data)) {
			$this->rows = count ($this->data);
			$this->cols = count ($this->data[0])+1;
			$this->_debug ("rows: ".$this->rows);
			$this->_debug ("columns: ".$this->cols);
		} else {
			$this->_error ("input data empty");
			return false;
		}
		$this->use_indent ($indent);
		$this->check_all = $chall;
		$this->chname = $chname;
	}

	/**	Custom error message handling.
	 */
	function _error ($msg) {
		info (msg ($msg));
	}

	/**	Special row rendering - plus view button.
	 *	@returns void
	 */
	function _table_rows () {
		// create rows from data
		for ($i=0; $i < $this->rows; $i++) {
			$tr_bonus = $this->tr_attributes[$i % count ($this->tr_attributes)];
			// print row
			echo "	<tr $tr_bonus>\n";
			for ($j=0; $j < $this->cols-1; $j++) {	// cols-1 ... to have colored header :-)
				$cell = $this->data[$i][$j];
				$td_bonus = $this->td_attributes[$j % count ($this->td_attributes)];
				if (($this->chboxes) && (in_array ($j, $this->chboxes_where))) {
					echo $this->indent."	<td $td_bonus>";
					?><input type="checkbox" value="<?= $cell?>" name="<?= $this->chbox_prefix.$cell?>"><?
					echo "</td>\n";
				} else
					echo $this->indent."	<td $td_bonus>".$this->style .  $cell ."</td>\n";
			}
			// end of row -> insert view button
			echo '		<td align="center" width="90">'; // FIXME?: width browser dependent (IE:86, MOZ:88, ..??)
			// FIXME: magic constants to fit in a window -> surely will be IE dependent
			$w = ($this->img_data[$i][1] < 600) ? $this->img_data[$i][1]+48 : 640;
			$h = ($this->img_data[$i][2] < 400) ? $this->img_data[$i][2]+65 : 480;
			?>
			<input type="button" value="view" name="view" onclick="
			winimg = window.open ('<?= $this->img_data[$i][0]?>', 'winimg', 'width=30, height=50, resizable=yes, scrollbars=yes');
			winimg.resizeTo (<?= $w ?>, <?= $h ?>);
			winimg.focus();
			"><input type="button" value="code" name="code" onclick="
			set_img_code ('<?= $this->img_data[$i][0];?>', '<?= $this->img_data[$i][1]?>', '<?= $this->img_data[$i][2]?>');">
<?			// window.document.title = '<?= $this->data[$i][1]? >';			 width=\"342\" height=\"333\"
			//<?= $this->_img_code ($this->img_data[$i][0], $this->img_data[$i][3]); ? >
			echo "</td>".$this->indent."</tr>";
		}
	}
	function _img_code ($file, $sizes) {
		echo '<img src="', $file, "\" $sizes >";
	}
	function _table_end () {
	?>
	</table>
	<table width="100%" border="0" cellpadding="0" cellspacing="0">
	<tr><td colspan="4" height="10"></td></tr>
	<tr>
		<td width="30"><b>Code:</b>&nbsp;&nbsp;</td>
		<td><input type="text" size="90" value="" name="img_code"></td>
	</tr>
	<tr>
		<td></td>
		<td align="right"><input 
			type="button" value="submit" name="submit"><input 
			type="button" value="close" name="close" onclick="self.close ();">
			<? help (msg ("image code")) ?></td>
	</tr>
	</table>
	</form>
<?	}
	function insert_script ($form_name) {
		$this->_script_check_all ();
		$this->_script_img_code ($form_name);
	}
	function _script_check_all () {
	}
	function _script_img_code ($form_name) { ?>
	<script language="JavaScript1.1" type="text/javascript">
	<!--
	function set_img_code (imgurl, imgw, imgh) {
		document.<?= $form_name?>.img_code.value = '<img src="'+imgurl+'" width="'+imgw+'" height="'+imgh+'">';
	}
	-->
	</script>
<?	}

} // class image_browser

?>