<?php

/*
 *	Article System
 *	Online journal management tool
 written in PHP/MySQL.
 *	This code is available at http://sourceforge.net/projects/artsys
 *
 *	Copyright (C) 2002 Jan Hnatek
 *	Distributed under the terms of the GNU General Public License
 *
 *	Date:	  07/05/2002
 *	Version:  0.1-1 (pre-alpha)      	
 */

###############################################################################
# main : the main object of admin part of ArtSys

/**
 *	The main object of admin part.
 *	
 *	@author		Jan Hnatek
 */
class main {
//--------//

	// VARIABLES
	
	/**	Name of the application.
	 *	This is displayed in title
	 * 	@var		string
	 *	@access		private
	 *	@see		get_title()
	 */
	var $name;
	
	/**	Array of module objects.
	 */
	var $modules = array ();
	
	/**	Index to $this->modules giving us the active section.
	 *	@var 	int
	 *	@access	private
	 */
	 var $active;

	// CONSTRUCTOR
	
	/**	Constructor of the main class.
	 *	Set the name as title of the pages and register modules according to given array of module names.
	 *	Set the currently active module.
	 *	
	 *	@param	$name string Name of the application.
	 *	@param	$parts array An associative array (name, module_name) of the parts (modules), 
	 *	which should be inserted into application.
	 *	@return	void
	 *	@access	public
	 *	
	 *	@see	display()
	 *	@see	module
	 */
	function main ($name, $parts) {
		global $section;
		$this->name = $name;
		// if $section is not in_array ($parts), somebody is trifling with querystring variables
		if (!in_array ($section, array_keys ($parts)))
			info ("This ain't gettin' you anywhere (I hope :-)");
		reset ($parts);
		while (list ($part, $modname) = each ($parts)) {
			//debug ("register part: '$part' with module: '$modname'");
			$active = ($section == $part) ? "true" : "";
			// create instances of registered modules
			if (class_exists ($modname)) {
				eval ("\$module =& new $modname ($active);");
				array_push ($this->modules, $module);
			}
			if ($section == $part) {
				// index of last inserted value, active module is then $this->modules[$this->active]
				$this->active = count ($this->modules) - 1;
				//debug ("active is : ".$this->modules[$this->active]->get_name());
			}
		}
	}

	// METHODS
	
	/**	Echoes results of menu() function.
	 *	@return void
	 *	@access public
	 */
	function display () {
		$this->menu ();
	}
	
	/**	The main menu display function.
	 *	Display links to/of all registered modules and then some globals (login info, time, logout button).
	 *	@return void
	 *	@access public
	 */
	function menu () {
		global $section, $subsection, $BASE_URL, $BASE_ADMIN_URL, $gui; 
		// prepare main menu items array
		$items = array ('\L');
		foreach ($this->modules as $module)
			array_push ($items, $module->main_link (), '\SS');
		array_pop ($items);
		array_push ($items,
			'\S', '<a href="'.$BASE_URL.'/index.php">'. msg ("public pages") .'</a>',
			'\S', $this->login_info (), 
			'\S', '<a href="'. $BASE_ADMIN_URL .'/main.php?sec=logout&sub=logout">'. msg ("logout") .'</a>',
			'\R'
		);
		$gui->menu ($items, 'menu', '', 'menusep');
	}
	
	/**	Returns currently active module.
	 *	@access	public
	 *	@return	object module
	 */
	function get_active () {
		return $this->modules[$this->active];
	}
	
	/**	Returns the title for the pages.
	 *	Intended to be used in &lt;title&gt; tag.
	 *	@return string
	 *	@access public
	 */
	function get_title () {
		global $section, $subsection;
		return "$this->name - $section:$subsection";
	}
	
	/**	Deploy scripts used in modules.
	 *	@access	public
	 *	@return	void
	 */
	function insert_script () { ?>
	<script language="JavaScript1.2" type="text/javascript">
	<!--
	function linkto (target_page) {
		document.location.href=target_page;
	}
	function createlist () {
		var list = "";
		for (var i=0; i < document.item_list.elements.length; i++) {
			if (document.item_list.elements[i].checked == true)
				// check if a number (we don't want to send "select all" checkbox value ("on") and similar
				if (!isNaN (document.item_list.elements[i].value))
					list = list + document.item_list.elements[i].value + ",";
		}
		return list;
	}
	function linklistto (target_page) {
		var list = createlist ();
		redir = target_page + "&list=" + list;
		if (list == "")
			alert ('<?= msg("no item selected")?>');
		else
			document.location.href=redir;
	}
	function confirmlinklistto (target_page, message) {
		var list = createlist ();
		redir = target_page + "&list=" + list;
		if (list == "")
			alert ('<?= msg("no item selected")?>');
		else if (confirm (message))
				document.location.href=redir;
	}
	function linkidto (target_page) {
		redir = target_page + "&id=" + document.items.id.value;
		//alert (redir);
		document.location.href=redir;
	}
	function confirmlinkidto (target_page, message) {
		redir = target_page + "&id=" + document.items.id.value;
		//alert (redir);
		if (confirm (message))
			document.location.href=redir;
	}
	-->
	</script>	
<?	}	// insert_script ()
	
	/*	Render login information (user, time, group ??)
	 *	@access	public
	 *	@return	string
	 */
	function login_info () {
		global $user_name;
		setlocale ("LC_TIME", "C");
		return "$user_name/" . strftime ("%X");
	}

}	// class main

?>