<?php

/*
 *	Article System
 *	Online journal management tool
 written in PHP/MySQL.
 *	This code is available at http://sourceforge.net/projects/artsys
 *
 *	Copyright (C) 2002 Jan Hnatek
 *	Distributed under the terms of the GNU General Public License
 *
 *	Date:	  07/05/2002
 *	Version:  0.1-1 (pre-alpha)      	
 */

###############################################################################
# module : an abstract parent object for ArtSys admin parts

/**
 *	An abstract class representing a module to ArtSys.<br>
 *	A module here should be a set of functionality upon the same type of data.
 *	<br>
 *	input menu example:
 <pre>
	$imenu = array (
			"list"	=> array ("test.php", 
					new button_new ( ... ), 
					new button_edit (), 
					new button_delete () ),
			"new"	=> array ("inc_template.php", 
					new button_save (), 
					new button_reset (), 
					new button_done (),
			),
		);
 </pre>
 *	
 *	@author		Jan Hnatek
 */
class module {
//----------//

	// VARIABLES
	
	/** Name of this module. 
	 *	Corresponds to the <code>$section</code> variable in the system.
	 *	It's also used as "text" to display on the link.
	 * 	@var		string
	 * 	@access		private
	 *	@see		main_link()
	 */
	var $name;
	
	/** Currently active subsection.
	 *	The subsection to display.
	 *	@var		string
	 *	@access		private
	 */
	var $subsection = "";
	
	/**	Activity value.
	 *	This should be set to true in constructor, when this module is active.
	 *	@access	private
	 *	@var	bool
	 */
	var	$active;
	
	/** Subsection description array.
	 *	Format explained in constructor.
	 *	@var	array
	 *	@access	private
	 *	@see	module,module_button
	 */
	var $menu = array ();
	
	/**	List of subsections, where the form will not be closed.
	 *	Typically "new", "edit". Means that the submit button of submenu will be used to submit the page's form.
	 *	@var	array
	 *	@access	private
	 */
	var $open_form = array ();

	// CONSTRUCTOR
	
	/**	An example constructor of the class (~virtual).
	 *	Accepts input menu and calls display function, which means drawing of the menu.
	 *	
	 *	@param	$name string The name of this module.
	 *	@param	$imenu special<br>
	 *	array ( <br>
	 *	"subsection_name_1"	=> array ("include_file_1", button, button, ...),<br>
	 *	"subsection_name_2"	=> array ("include_file_2", button, button, ...),<br>
	 *	... );<br>
	 *	where 'button' is a <code>module_button</code> object.
	 *	
	 *	@return	void
	 *	@access	public
	 *	
	 *	@see	module_button
	 *	@see	display()
	 */
	function module ($name, $imenu, $iactive) {
		global $section, $subsection;
		$this->name = $name;
		$this->subsection = $subsection;
		$this->menu = $imenu;
		$this->active = $iactive;
		$this->display ();
	}

	// METHODS
	
	/**	Echoes results of render() function.
	 *	@access private
	 *	@return void
	 */
	function display () {
		return $this->render ();
	}
	
	/**	Renders the "submenu", ie. the menu of this module.
	 *	The menu is defined in constructor, see top of this page.
	 *	It is called by display() function
	 *	@return void
	 *	@access private
	 */
	function render () {
		global $subsection, $gui;
		// get 'menu_button' array corresponding to current subsection
		$active = &$this->menu[$this->subsection];
		// prepare arrays for the menu
		$items = array ('\L');
		$gui->menu_begin ($items, 'menu', '', 'menusep');
// FIXME: where does the FORM belong ????
// most likely it won't be good like this :-(
?>
		<form name="items" method="post" action="main.php">
<?		
		$items = array ($active[1]->render ());
		for ($i=2; $i < count ($active); $i++)
			array_push ($items, '\SS', $active[$i]->render ());
		array_push ($items, '\R');
		// render menu
		$gui->menu_next ($items);
		if ($this->open_form () == false)
			echo '</form>';
		$gui->menu_end ();
	}
	
	/**	Check if currently active subsection's form should be closed.
	 *	These are typically "new", "edit". Means that the submit button of submenu will be used to submit the page's form.
	 *	Used in <code>module</code>'s <code>render()</code> method.
	 *	@return	bool
	 *	@access	public
	 */
	function open_form () {
		global $subsection;
		//debug ("open_form: check for $subsection in array with ". count ($this->open_form). " items");
		return in_array ($subsection, $this->open_form);
	}
	
	/**	Set active subsection according to global with respect to local <code>menu</code> structure.
	 *	Ie. if the global subsection is not present here, set it to a correct value and possibly export.
	 *	Should be called from constructor after setting up the <code>menu</code> array.
	 *	@return	void
	 *	@access	private
	 */
	function set_sub () {
		global $subsection;
		//debug ("test for: $subsection");
		if (in_array ($subsection, array_keys ($this->menu))) {
			// the requested subsection is in this module
			$this->subsection = $subsection;
		} else {
			// it's not here, set to first of $this->menu, both with the global value
			reset ($this->menu);
			list ($key, $junk) = each ($this->menu);
			//debug ("false, set it to: ".$key);
			$this->subsection = $key;
			if ($this->active)
				$subsection = $this->subsection;
		}
	}
	
	/**	Return name of this module.
	 *	@access	public
	 *	@return	string
	 */
	function get_name () {
		return $this->name;
	}
	
	/**	Return current include file name.
	 *	Or return DEFAULT_INCLUDE_FILE if include file does not exist, so that we don't get errors.
	 *	@access public
	 *	@return string
	 */
	function get_include () {
		global $DEFAULT_INCLUDE_FILE, $subsection;
		// get first item from array corresponding to current subsection
		$include_file = $this->menu[$this->subsection][0];
		if (($include_file == "") || (!file_exists ($include_file)))
			$include_file = $DEFAULT_INCLUDE_FILE;
		//debug ($include_file);
		return $include_file;
	}
	
	/**	Echoes a self-pointing anchor tag.
	 *	@access	public
	 *	@return	void
	 */
	function main_link () {
		global $section, $BASE_ADMIN_URL;
		if ($section != $this->name)
			return "<a href=\"$BASE_ADMIN_URL/main.php?sec=$this->name&sub=list\">$this->name</a>";
		else
			return "$this->name";
	}

}	// class module

?>