<?php

/**	
 *	Tag Attributes Set.<br>
 *	A container for HTML tag attributes.<br>
 *	
 *	The idea if quite simple. It is an object, that consists of an associative array,
 *	that contains tag names as keys with corresponding
 *	string of tag attributes to be used with that tag.<br>
 *	<br>
 *	Note: It's just important, that the classes using this object have the tags, they're
 *	using, documented.<br>It might also be a good idea to name the custom tags in format
 *	"tag.custom_name", <br>so that it's obvious, where (by which tag) is it used.<br><br>
 *	
 *	Something like this may appear in the head of such classes: <br>
 *	
 *	<b>Notes:</b><br>
 *	Using <code>taset</code>: {"a", "a.special" [inherited "table", "tr", "td"]}<br>
 *	
 *	@author	Jan Hnatek
 */
class taset {
//---------//

	// VARIABLES
	//
	/**	Attribute data container.
	 *	1D associative array with tag names (or virtually any identifier) as keys<br>
	 *	Example: <br>
	 *	<pre>
	 	$data["a"]
		$data["special"]
	 *	</pre>
	 */
	var $data;

	// CONSTRUCTOR
	//
	/**	Constructor of the class taset. Get attribute data from given associative array.<br>
	 *	@param	$in		asoc.array	Attribute data.
	 *	@return void
	 *	@access	public
	 */
	function taset ($in=0) {
		if (is_array ($in))
			$this->data = $in;
		else
			$this->data = array ();
	}


	// METHODS
	//
	/**	Modify attribute data for given tag.
	 *	@param	$tag	string	Name of the tag to modify.
	 *	@param	$attrib	string	New attributes for this tag.
	 *	@return void
	 *	@access	public
	 */
	function set ($tag, $attrib) {
		$this->data[$tag] = $attrib;
	}
	
	/**	Get attribute data for given tag.
	 *	@param	$tag	string	Name of the tag to get.
	 *	@return void
	 *	@access	public
	 */
	function get ($tag) {
		return $this->data[$tag];
	}
	
	/**	Check existence of attributes for given tag. Empty tags ("") will fail too.
	 *	@param	$tag	string	Name of the tag to check.
	 *	@return void
	 *	@access	public
	 */
	 function exists ($tag) {
		if ($this->data[$tag] != "")
			return true;
		else
			return false;
	}

}	// class taset

?>
