<?php

/*
 *	Article System
 *	Online journal management tool
 written in PHP/MySQL.
 *	This code is available at http://sourceforge.net/projects/artsys
 *
 *	Copyright (C) 2002 Jan Hnatek
 *	Distributed under the terms of the GNU General Public License
 *
 *	Date:	  07/05/2002
 *	Version:  0.1-1 (pre-alpha)      	
 */

###############################################################################
# UPLOAD : A CLASS TO HANDLE FILE UPLOADS
#

 /*	DEBUG:
 	------
	uncomment this to get debug information
 */
define('UPLOAD_DEBUG', true);

/**	
 *	A class to easily handle file uploads.
 *	
 *	@version	1.1, 20.3.2002
 *	@author		Jan Hnatek
 */
class upload
//--------//
{

	// VARIABLES
	
	// upload directory
	var $upload_dir;
	// name of submit button
	var $submit;
	
	// feature enable/disable
	var $check_ext = false;
	var $extensions;
	
	var $check_type = false;
	var $types;
	
	var $check_filesize = false;
	var $maxsize;
	var $check_imgsize = false;
	var $maxx;
	var $maxy;
	
	var $error;
	var $errors = array (
		"e_file" => "Input filename error (empty filename / nonexistent file / browser maxsize exceeded).",
		"e_size" => "Failed size check in this class.",
		"e_type" => "Wrong file type.",
		"e_ext"  => "Wrong file extension.",
		"e_imgs" => "Maximum size for image exceeded.",
		"e_copy" => "Failed to copy into destination directory.",
		"e_exist"=> "File already exists in destination folder.",
		"ok" 	 => "File succesfully uploaded.",
		""		 => ""
	);
	
	var $filedef = 'upload_file';



	/**	Constructor for <code>upload</code>.
	 *	@public
	 *	@param	$dir		upload directory (file destination)
	 *	@param	$maxsize	maximum allowable file size in kBytes ("0" here means no check)
	 *	@param	$errors		asoc.array of error messages, use only to redefine, take original as basis
	 *	@return	boolean
	 */
    function upload ($dir, $maxsize="0", $ierrors='') {
		$this->upload_dir = $dir;
		if (is_array ($ierrors))
			$this->errors = $ierrors;
		if ($maxsize != "0") {
			$this->check_filesize = true;
			$this->maxsize = $maxsize;
		}
	}


	// PRIVATE METHODS
		
		/**	Simple debug function for this class
		 *	@private
		 *	@param	$text	text to print.
		 *	@return	void
		 */
		function _debug ($text) {
			if (defined('UPLOAD_DEBUG'))
				echo "\n<code style=\"color:gray\">$text</code><br>\n";
		}
		
		/** Apply all given checks on the uploaded file (size, type ...). See <code>get_file</code> on return values.
		 * @private
		 * @return special
		 */
		function _check_file () {
			global $HTTP_POST_FILES;
			// extension check
			if ($this->check_ext) {
				$parts = preg_split ("/\.+/", strtolower ($HTTP_POST_FILES[$this->filedef]['name']) );
				$file_ext = $parts [count ($parts)-1];
				$this->_debug ("ext: ".$file_ext);
				if (!in_array ($file_ext, $this->extensions))
					return $this->error = "e_ext";
			}
			// type check
			if ($this->check_type) {
				$this->_debug ("type: ".$HTTP_POST_FILES[$this->filedef]['type']);
				if (!in_array ($HTTP_POST_FILES[$this->filedef]['type'], $this->types))
					return $this->error = "e_type";
			}
			// file size check
			if ($this->check_filesize) {
				$this->_debug ("size: ". filesize ($HTTP_POST_FILES[$this->filedef]['tmp_name'])/1024);
				if ($this->maxsize < filesize ($HTTP_POST_FILES[$this->filedef]['tmp_name'])/1024)
					return $this->error = "e_size";
			}
			// image size check
			if ($this->check_imgsize) {
				$size = GetImageSize ($HTTP_POST_FILES[$this->filedef]['tmp_name']);
				$this->_debug ("size x: $size[0]/$this->maxx, size y: $size[1]/$this->maxy");
				if (($size[0] > $this->maxx) || ($size[1] > $this->maxy))
					return $this->error = "e_imgs";
			}
			// check if file exists in destination
			if (file_exists ($this->upload_dir."/". strtolower ($HTTP_POST_FILES[$this->filedef]['name']) ))
				return $this->error = "e_exist";
			
			return $this->error = "ok";
		}


	// PUBLIC METHODS
	
	/**	Enable extension check. Allow only given extensions.
	 *	@param	$exts	array of allowable file extensions
	 *	@return void
	 */
	function set_check_extension ($exts) {
		if (count ($exts)) {
			$this->check_ext = true;
			$this->extensions = $exts;
		} else
			$this->_debug ("no extensions given");
	}
	
	/**	Enable file type check. Allow only given types.
	 *	@param	$types	array of allowable file types
	 *	@return void
	 */
	function set_check_type ($types) {
		if (count ($types)) {
			$this->check_type = true;
			$this->types = $types;
		} else
			$this->_debug ("no types given");
	}
	
	/**	Enable checking of image sizes.
	 *	@param	$maxx	Maximum x size.
	 *	@param	$maxy	Maximum y size.
	 *	@return void
	 */
	function set_check_imgsize ($maxx, $maxy) {
		if ($maxx && $maxy) {
			$this->check_imgsize = true;
			$this->maxx = $maxx;
			$this->maxy = $maxy;
		} else
			$this->_debug ("wrong img size input");
	}
	
	/** Get the uploaded file. If the input values are set, apply all file tests and upload the given file.<br>
	 *	@return "index" to errors array
 	 */
	function get_file () {
		global ${$this->submit}, $HTTP_POST_FILES; //, $file, $file_name;
		//$this->_debug (${$this->submit});
		
		// do we have file submitted ?
		if (isset (${$this->submit})) {
			// FIXME: In PHP 4.1.0 or later, $_FILES should be used instead of $HTTP_POST_FILES.
			//$this->_debug ($HTTP_POST_FILES[$this->filedef]['name']);
			//$this->_debug ($HTTP_POST_FILES[$this->filedef]['tmp_name']);
			//$this->_debug ($this->upload_dir);
			if (is_uploaded_file ($HTTP_POST_FILES[$this->filedef]['tmp_name'])) {
				// apply checks
				if ($this->_check_file () == "ok") {
					// move to upload dir and delete from tmp
					$OK = copy ($HTTP_POST_FILES[$this->filedef]['tmp_name'], 
						$this->upload_dir."/". strtolower ($HTTP_POST_FILES[$this->filedef]['name']) );
					unlink ($HTTP_POST_FILES[$this->filedef]['tmp_name']);
					if ($OK)	return $this->error = "ok";
					else		return $this->error = "e_copy";
				} else
					// checks failed
					return $this->error;
			} else {
				// no file available .. ???
				$this->_debug ("Possible file upload attack. Filename: " . $HTTP_POST_FILES[$this->filedef]['name']);
				return $this->error = "e_file";
			}
		}
	}
	
    /**	Returns text of the last error.
     *	@return string
     *	@access public
     */
	function get_error () {
		return $this->error;
	}
	
    /**	Prints formatted error message.
     *	Applications should call this function at a 'placeholder' that displays an error message if error occurs.
     *	@return void
     *	@access public
     */
	function error_report () {
		print ("<br>". $this->errors[$this->error]);
	}
	
	/**	Insert the script form with a table. Use it as an example of usage to write your own input form.
	 *	@param	$submit		name of the submit button
	 *	@returns void
	 */
	function insert_form ($submit="upload", $msg="send file", $table_attr="", $p_attr="") {
		global $PHP_SELF;
		$this->submit = $submit;?>
		<form method="post" enctype="multipart/form-data" action="<?= $PHP_SELF?>">
<?			// use browser filesize recommendations, in bytes ...
			if ($this->maxsize) : ?>
		<input type="hidden" name="MAX_FILE_SIZE" value="<?= $this->maxsize * 1024 ?>">
<?			endif; ?>
		<p><b>Upload:</b>&nbsp;
			<input type="file" size="40" name="<?= $this->filedef?>"><input 
			type="submit" name="<?= $this->submit?>" value="<?= $msg?>">
		</form>
		</p>
<?	}


}	// EOclass

?>
