<?php

/*
 *	Article System
 *	Online journal management tool
 written in PHP/MySQL.
 *	This code is available at http://sourceforge.net/projects/artsys
 *
 *	Copyright (C) 2002 Jan Hnatek
 *	Distributed under the terms of the GNU General Public License
 *
 *	Date:	  07/05/2002
 *	Version:  0.1-1 (pre-alpha)      	
 */

###############################################################################
# rights : rights checking object for admin part of ArtSys

/**
 *	User rights management for ArtSys
 *	
 *	@author		Jan Hnatek
 */
class user {
//--------//

	// VARIABLES
	
	/**	User id of current user.
	 * 	@var		int
	 * 	@access		private
	 */
	 var $id;
	 var $realname;
	 var $username;
	 var $email;
	 var $signature;
	 var $blocked;
	 var $group;
	 var $rights = array ();

	// CONSTRUCTOR

	/**	Constructor of the rights class.
	 *	Fill in user information and set rights array according to db.
	 *
	 *	@param	$id int User id of this user.
	 *	@access	public
	 */
	function user ($id) {
		global $db;
		$this->id = $id;
		// get user information from db
		$RS = $db->exec ("SELECT DISTINCTROW U.id, U.name as uname, U.username, U.email, U.signature, U.blocked, G.*
			FROM Users U, Ugroups G WHERE (U.id='$id') AND (U.ugroup=G.id);"); // , 1
		// TODO: unify these messages
		test ($RS, "internal error: failed to get user information<br>\n");

		// distribute values
		$user = $db->get_result_object ();
		$this->realname = $user->uname; // U.name
		$this->username = $user->username;
		$this->email = $user->email;
		$this->signature = $user->signature;
		$this->blocked = $user->blocked;
		$this->group = $user->name;	// G.name
		$this->rights = array (
		    "a_read"	=> $user->a_read,	      # read unpublished articles
		    "a_create"	=> $user->a_create,	      # submit new articles
		    "a_correct"	=> $user->a_correct,      # edit and correct else's articles
		    "a_approve"	=> $user->a_approve,      # sign an article as finished for next issue, edit approved articles
		    "issues"	=> $user->issues,		  # issue management
		    "users"		=> $user->users,	      # users modification (add, delete, block)
			"agroups"	=> $user->agroups,	      # group modification (add, delete)
			"admin"		=> $user->admin,          # admin tasks
			);
	}

	// METHODS
	
	/**	Rights checking routine.
	 *	Returns true/false depending on current users rights on given subject.
	 *	@param	$right string Subject to check rights of.
	 *	@access	public
	 *	@return	bool
	 */
	function check_my ($right) {
		return ($this->rights[$right] == 1);
	}
	
	/**	Returns parts array depending on user rights.
	 *	Used by the <code>main</code> class.<br>
	 *	@return	<code>$parts</code> .. is an associative array with (section, module_name) pairs.
	 *	@access	public
	 */
	function get_parts () {
		$parts = array ();
		if ($this->rights["a_read"] || $this->rights["a_create"] || $this->rights["a_correct"] || $this->rights["a_approve"]);
			$parts["articles"] = "module_articles";
		if ($this->rights["agroups"])
			$parts["groups"] = "module_groups";
		if ($this->rights["issues"])
			$parts["issues"] = "module_issues";
		if ($this->rights["users"])
			$parts["users"] = "module_users_admin";
			//$parts["users"] = "module_users_normal";
		else
			$parts["users"] = "module_users_normal";
   		if ($this->rights["admin"])
			$parts["admin"] = "module_admin";
		return $parts;
	}

}	// class main

?>