##
## Article System : database dump
##

###############################################################################
# User groups
#

DROP TABLE IF EXISTS Ugroups;
CREATE TABLE Ugroups (
    id INT(11) NOT NULL auto_increment,
    name VARCHAR(255) NOT NULL,
    
    ## rights
    
      # read unpublished articles
    a_read TINYINT(1) DEFAULT '0' NOT NULL,
      # submit new/edit own articles
    a_create TINYINT(1) DEFAULT '0' NOT NULL,
      # edit and correct else's articles
    a_correct TINYINT(1) DEFAULT '0' NOT NULL,
      # sign an article as finished for next issue, delete other's articles
    a_approve TINYINT(1) DEFAULT '0' NOT NULL,
      # create, publish, ... issues
    issues TINYINT(1) DEFAULT '0' NOT NULL,
      # users modification (add, delete, block)
    users TINYINT(1) DEFAULT '0' NOT NULL,
      # groups modification (add, delete)
    agroups TINYINT(1) DEFAULT '0' NOT NULL,
	  # admin flag
	admin TINYINT(1) DEFAULT '0' NOT NULL,
      
    CONSTRAINT PK_Ugroups PRIMARY KEY (id),
    CONSTRAINT UNQ_ugroup_name UNIQUE KEY (name),
    UNIQUE INDEX IDX_Ugroups_id (id),
    UNIQUE INDEX IDX_Ugroups_name (name)
);
#						
				       r  cre cor app iss use agr adm
INSERT INTO Ugroups VALUES ('1','guests',     '0','0','0','0','0','0','0','0');
INSERT INTO Ugroups VALUES ('2','readers',    '1','0','0','0','0','0','0','0');
INSERT INTO Ugroups VALUES ('3','authors',    '1','1','0','0','0','0','0','0');
INSERT INTO Ugroups VALUES ('4','editors',    '1','1','1','0','0','0','0','0');
INSERT INTO Ugroups VALUES ('5','publishers', '1','1','1','1','0','0','1','0');
INSERT INTO Ugroups VALUES ('6','admins',     '1','1','1','1','1','1','1','1');



###############################################################################
# Users
#

DROP TABLE IF EXISTS Users;
CREATE TABLE Users (
      id INT(11) NOT NULL auto_increment,
      name VARCHAR(255) NOT NULL,
      username VARCHAR(255) NOT NULL,
      email VARCHAR(255) NULL,
      signature VARCHAR(255) NULL,
      password VARCHAR(255) NOT NULL,
      blocked TINYINT(1) DEFAULT '0' NOT NULL,
      ugroup INT(11) DEFAULT '6' NOT NULL,

      CONSTRAINT PK_Users PRIMARY KEY (id),
      CONSTRAINT UNQ_username UNIQUE KEY (username),
      UNIQUE INDEX IDX_Users_id (id),
      UNIQUE INDEX IDX_Users_username (username)
);

# root
INSERT INTO Users VALUES ('1','administrator',	'root',	'root@artsys','','d5fdd4f1765bcf3e9d19f42e8ac11066','0','6');
# guest user, password 'guest'
INSERT INTO Users VALUES ('2','guest',		'guest',	'guest@artsys','','084e0343a0486ff05530df6c705c8bb4','0','1');
# test default to-delete users, password 'guest'
INSERT INTO Users VALUES ('3','author',		'author',	'test@artsys','','084e0343a0486ff05530df6c705c8bb4','0','3');
INSERT INTO Users VALUES ('4','editor',		'editor',	'test@artsys','','084e0343a0486ff05530df6c705c8bb4','0','4');
INSERT INTO Users VALUES ('5','publisher',	'publisher','test@artsys','','084e0343a0486ff05530df6c705c8bb4','0','5');
INSERT INTO Users VALUES ('6','reader',		'reader',	'test@artsys','','084e0343a0486ff05530df6c705c8bb4','0','2');


###############################################################################
# Article groups
#

DROP TABLE IF EXISTS Agroups;
CREATE TABLE Agroups (
      id INT(11) NOT NULL auto_increment,
      name VARCHAR(255) NOT NULL,
      menu_text VARCHAR(100) NULL,
      description VARCHAR(255) NULL,
	  exported TINYINT(1) DEFAULT '0' NOT NULL,
      
      CONSTRAINT PK_Agroups PRIMARY KEY (id),
      CONSTRAINT UNQ_agroup_name UNIQUE KEY (name),
      UNIQUE INDEX IDX_Agroup_id (id),
      UNIQUE INDEX IDX_Agroup_name (name)
);

INSERT INTO Agroups VALUES ('1','test','test','A group for testing purposes', '0');


###############################################################################
# Articles
#

DROP TABLE IF EXISTS Articles;
	CREATE TABLE Articles (
	id INT(11) NOT NULL auto_increment,
	
	title text NOT NULL,
	subtitle text NULL,
	content text NOT NULL,
	keywords VARCHAR(255) NULL,
	# 'implicit/initial group' is kinda redundant, but helps alot
	igroup INT(11) NULL,
	counter INT(11) DEFAULT '0' NULL,
	
	# authors information
	author INT(11) DEFAULT '0' NOT NULL,
	editor INT(11) DEFAULT '0' NOT NULL,
	publisher INT(11) DEFAULT '0' NOT NULL,
	# textual author information (default .. name from user with id==id_author)
	signature VARCHAR(255) NOT NULL,
	
	## state information
	
	 # author has finished his work on the article
	author_done TINYINT(1) DEFAULT '0' NOT NULL,
	 # editor has finished his work on the article
	editor_done TINYINT(1) DEFAULT '0' NOT NULL,
	 # admin has approved the article
	approved TINYINT(1) DEFAULT '0' NOT NULL,
	
	# dates
	created_on DATETIME Null,
	finished_on DATETIME Null,
	published_on DATETIME Null,
	
	## issue / menu information
	
	# issue id, if any
	issue INT(11) NULL,
	# issue name : another redundant information to help with retrieve info about article
	issue_name VARCHAR(100) DEFAULT '' NULL,
	# item name in the menu of an issue, default should be the title of this article
	menu_title VARCHAR(100) NOT NULL,
	# issue group name this article belongs to
	menu_group VARCHAR(100) NOT NULL,
	# order in the menu of an issue
	iorder INT(4) DEFAULT '0' NOT NULL,
	
	CONSTRAINT PK_Articles PRIMARY KEY (id),
	UNIQUE INDEX IDX_Articles_id (id)
	# check not supported by MySQL :-(
	#CHECK ( (issue IS NOT NULL AND issue_name != '') OR
	#		(issue IS NULL AND issue_name = '') )
);	

INSERT INTO Articles SET
	title = 'Article System', 
	content = 'ArtSys (Article System) is a support tool for creating internet-based journal. It\'s written using HTML/PHP/MySQL.',
	keywords = 'ArtSys, PHP, MySQL', 
	author = '1', editor = '0', publisher = '0',
	signature = 'root',
	author_done = '1', editor_done = '1', approved = '1',
	created_on = '2001-11-18 20:52:00', finished_on = '2001-11-18 20:52:00', published_on = '2001-11-18 20:52:00',
	issue = '1', issue_name = 'Issue 0', menu_title = 'the only published ...', iorder = '0';
INSERT INTO Articles SET
	title = 'article test (unfinished)', subtitle = 'this is subtitle', content = 'bla bla bla', 
	author = '1', editor = '0', publisher = '0', author_done = '0', editor_done = '0', approved = '0',
	created_on = '2001-11-18 20:52:00';


###############################################################################
# Ainsertion : articles in groups
#

DROP TABLE IF EXISTS Ainsertion;
CREATE TABLE Ainsertion (
      article INT(11) NOT NULL,
      agroup INT(11) NOT NULL,
      
      CONSTRAINT UNQ_Ainsertion_1 Unique (article, agroup),
      UNIQUE INDEX IDX_Ainsertion_article_agroup (article, agroup)
);

# insert into 'test' group
INSERT INTO Ainsertion VALUES ('1','1');
INSERT INTO Ainsertion VALUES ('2','1');


###############################################################################
# Issues
#

DROP TABLE IF EXISTS Issues;
CREATE TABLE Issues (
      id INT(11) NOT NULL auto_increment,
      name VARCHAR(100) NOT NULL,
      subtitle VARCHAR(100) NULL,
        # this should be '1' only by currently active issue
      current TINYINT(1) DEFAULT '0',
        # issue can be current/archived/invisible
      archived TINYINT(1) DEFAULT '0',
      published_on DATETIME NOT NULL,
      
      CONSTRAINT PK_Issues PRIMARY KEY (id),
      CONSTRAINT UNQ_issue_name UNIQUE KEY (name),
      UNIQUE INDEX IDX_Issues_id (id),
      UNIQUE INDEX IDX_Issues_name (name)
);

INSERT INTO Issues VALUES ('1','issue 0','The very first one ...','0','0','2001-11-18 21:00:00');


###############################################################################
# Arelated
#

DROP TABLE IF EXISTS Arelated;
CREATE TABLE Arelated (
      id_me INT(11) NOT NULL,
      id_other INT(11) NOT NULL,
      
      CONSTRAINT UNQ_Arelated_1 UNIQUE (id_me, id_other),
      UNIQUE INDEX IDX_Arelated_me_other (id_me, id_other)
);


###############################################################################
# MailTo
#

DROP TABLE IF EXISTS Mailto;
CREATE TABLE Mailto (
      id INT(11) NOT NULL,
      email VARCHAR(255) NOT NULL,
      name VARCHAR(255) Null,
      blocked INT(11) NOT NULL,
      
      CONSTRAINT PK_Mailto PRIMARY KEY (id),
      UNIQUE INDEX IDX_Mailto_id (id)
);


###############################################################################
# Sessions
#

DROP TABLE IF EXISTS Sessions;
CREATE TABLE Sessions (
    id VARCHAR(64) DEFAULT '0' NOT NULL,
    userid INT(11),
    username VARCHAR(255) NOT NULL,
	ip VARCHAR(255) NOT NULL,
    time INT(14),
    
    CONSTRAINT PK_Sessions PRIMARY KEY (id),
    UNIQUE INDEX IDX_Sessions_id (id)
);
